Renamed templates + added some filters for mail order
[mailer.git] / js.php
diff --git a/js.php b/js.php
index c4e57f9ae3fecd64437fb4beda96f13a6ccc9548..5594b86993c92f76793bacf83324b8cc1bf4c4f7 100644 (file)
--- a/js.php
+++ b/js.php
@@ -1,7 +1,7 @@
 <?php
 /************************************************************************
- * MXChange v0.2.1                                    Start: 10/15/2008 *
- * ===============                              Last change: 10/15/2008 *
+ * Mailer v0.2.1-FINAL                                Start: 10/15/2008 *
+ * ===================                          Last change: 10/15/2008 *
  *                                                                      *
  * -------------------------------------------------------------------- *
  * File              : js.php                                           *
  * $Date::                                                            $ *
  * $Tag:: 0.2.1-FINAL                                                 $ *
  * $Author::                                                          $ *
- * Needs to be in all Files and every File needs "svn propset           *
- * svn:keywords Date Revision" (autoprobset!) at least!!!!!!            *
  * -------------------------------------------------------------------- *
  * Copyright (c) 2003 - 2009 by Roland Haeder                           *
- * For more information visit: http://www.mxchange.org                  *
+ * Copyright (c) 2009 - 2013 by Mailer Developer Team                   *
+ * For more information visit: http://mxchange.org                      *
  *                                                                      *
  * This program is free software; you can redistribute it and/or modify *
  * it under the terms of the GNU General Public License as published by *
  * MA  02110-1301  USA                                                  *
  ************************************************************************/
 
+// XDEBUG call
+//* DEBUG: */ xdebug_start_trace();
+
 // Load security stuff here
 require('inc/libs/security_functions.php');
 
-// This is a fake-CSS file loader, more a JavaScript loader...
-// This is in one way good and in one not. The whole reset part will be
-// by-passed even in this "faked" CSS mode. The bad news is that this makes all
-// JS calls on this script to CSS calls. So no real "request" like in MVC
-// pattern is given...
-//
-// But mxchange 0.3.0 will show that in better way! :D :D :D
-$GLOBALS['output_mode'] = 1;
-$GLOBALS['module'] = 'js';
+// Init start time
+$GLOBALS['__start_time'] = microtime(TRUE);
+
+/*
+ * This is a fake-CSS file loader, more a JavaScript loader...
+ * This is in one way good and in one not. The whole reset part will be
+ * by-passed even in this "faked" CSS mode. The bad news is that this makes all
+ * JS calls on this script to CSS calls. So no real "request" like in MVC
+ * pattern is given...
+ *
+ * But Mailer-Project 0.3.0 will show that in better way! :D :D :D
+ */
+$GLOBALS['__module']      = 'js';
+$GLOBALS['__output_mode'] = 1;
 
 // Load the required file(s)
 require('inc/config-global.php');
 
+// Set header and HTTP status
+setContentType('text/javascript');
+setHttpStatus('404 Not Found');
+
 // Is 'js' is provied?
 if (isGetRequestElementSet('js')) {
-       // Set header
-       setContentType('text/javascript');
-
        // Load header
        loadIncludeOnce('inc/header.php');
 
        // Prepare include file for looking
-       $inc = sprintf("inc/js/js-%s.php",
-               getRequestElement('js')
-       );
+       $inc = sprintf('inc/js/js-%s.php', getRequestElement('js'));
 
        // Is that file readable?
        if (isIncludeReadable($inc)) {
+               // Okay, found
+               setHttpStatus('200 OK');
+
                // Include it
                loadIncludeOnce($inc);
        } // END - if
@@ -76,7 +85,7 @@ if (isGetRequestElementSet('js')) {
 } // END - if
 
 // Shutdown
-shutdown();
+doShutdown();
 
 // [EOF]
 ?>